@@ -8,11 +8,11 @@ String::Any::Extensions - Get extensions from string possible for files.
  
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =cut
 
-our $VERSION = '0.01';    # VERSION
+our $VERSION = '0.02';    # VERSION
 
 use utf8;
 use strict;
@@ -50,7 +50,7 @@ Parse extension from file string.
 =cut
 
 sub extension {
-    my ($extension) = $_[0] =~ /((\.[^.\s]+)+)$/;
+    my ($extension) = $_[0] =~ /((\.[^.\s|(\/|\\|::]+)+)$/;
     return $extension;
 }
 
